#
# spec file for package python-gprof2dot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-gprof2dot
Version:        2024.6.6
Release:        1.3
Summary:        Script to generate a dot graph from the output of several profilers
License:        LGPL-3.0-or-later
URL:            https://github.com/jrfonseca/gprof2dot
Source:         https://files.pythonhosted.org/packages/source/g/gprof2dot/gprof2dot-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
GProf2Dot.py is a Python script to convert the output from many
profilers into a dot graph.

%prep
%setup -q -n gprof2dot-%{version}
sed -i -e '/^#!\//, 1d' gprof2dot.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/gprof2dot
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative gprof2dot

%postun
%python_uninstall_alternative gprof2dot

%files %{python_files}
%license LICENSE.txt
%doc README.md
%python_alternative %{_bindir}/gprof2dot
%{python_sitelib}/gprof2dot.py
%pycache_only %{python_sitelib}/__pycache__/gprof2dot*
%{python_sitelib}/gprof2dot-%{version}.dist-info

%changelog
* Fri Jun  7 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.06.06:
  * Change http to https in LICENSE.txt
  * Added support for simulated/embedded gprof output
  * Fix typos in readme
  * Make GitHub Actions cover oldest and youngest Pythons alive
  * Stop Codecov CI from failing on forks
  * Trigger `testOnly.yml` workflow when its content changes
  * Drop Python 2.7 leftovers + require Python >=3.8
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 2022.7.29.
  * Add twine check --strict to CI
  * Convert setup.py to setup.cfg
  * Merge branch 'pull-71'
  * Added a test for the flag --function-list; made differences in generated files count in test criterion.
  * Added documentation, made test more stringent, added a github/actions script to test only
  * Added flag --list-functions; make program runnable in Python2.7 and Python3; description included in documentation
  * github-actions: Test Python 3.8.
  * Bump version.
  * github: Switch from CircleCI to GitHub Actions.
  * Update gprof2dot.py (#66)
  * docs: fix simple typo, generted -> generated
  * travis: Drop integration.
  * travis: Upgrade to Ubuntu 19.04.
  * Bump version.
  * add keyword argv to main, allowing calls like:
  * Sum call counts in JSON format.
  * Add dtrace support.
  * Add build badges.
  * travis: Disable deployment.
  * circleci: Integrate.
  * Add --nodel-label option to specify the measurements shown on the node label(s).
  * Don't hardcode theme names in opt parsing code
  * travis: Migrate to VM infrastructure.
  * travis: Upgrade to Xenial.
  * Fix a typo in gprof2dot.py
  * Update instructions for installing dependencies on Linux.
  * fix Profile.prune() for cases when filename is not set
  * Remove mentions to hotshot profile.
  * Add README and LICENSE to the manifest.
  * Rename README.mardkown to README.md
  * Deprecated: python 2.6
  * Add US spelling for option to color nodes by self-time.
  * Update password.
  * Update setup comments.
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed May  6 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to version 2019.11.30:
  * add keyword argv to main
  * Sum call counts in JSON format.
  * Add dtrace support.
  * Add --nodel-label option to specify the measurements shown
  * Don't hardcode theme names in opt parsing code
  * Fix a typo in gprof2dot.py
  * fix Profile.prune() for cases when filename is not set
  * Add README and LICENSE to the manifest.
- Drop Source10 (copy of LICENSE), now included in upstream tarball.
* Wed Jan  9 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed May 16 2018 toddrme2178@gmail.com
- Update to version 2017.9.19
  * Update password.
  * Ignore # comments anywhere on callgrind files.
  * Skip header '# callgrind format' if any.
  * Improved profile pruning abilities
  * Avoid ZipFile open mode 'U'.
  * Make assertion check robust against computational inaccuracies.
  * Truncate function names to avoid labels larger than 16Kb.
  * Update for changes if perf output.
  * Fix printing output on stdout in Python 3.5.1.
  * Prevent ZeroDivisionError when options.colour_nodes_by_selftime is set
  * Scale node weights when coloring nodes by selftime
  * Add colour-nodes-by-selftime option
  * Ranking of cycle functions
  * Improve implementation of Tarjan's algorithm to search for cycles.
- Implement single-spec version
* Tue May  3 2016 foss@grueninger.de
- update to version 2015.12.01
  no changelog available
* Thu Jun 26 2014 hpj@urpla.net
- initial build: 2014.03.12
